@@ -1,4 +1,4 @@
-# Copyright 2021 CR.Sparse Development Team
+# Copyright 2021 CR-Suite Development Team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 
 import jax.numpy as jnp
 
-from cr.sparse.la import solve_Lx_b, solve_LTx_b, solve_Ux_b, solve_UTx_b
+from cr.nimble import solve_Lx_b, solve_LTx_b, solve_Ux_b, solve_UTx_b
 
 
 def abs_max_idx(h):
