@@ -50,4 +50,10 @@ from cr.sparse._src.dict.props import (
 
 from cr.sparse._src.dict.comparison import (
     matching_atoms_ratio
-)
\ No newline at end of file
+)
+
+
+from cr.sparse._src.dict.grass import (
+    build_grassmannian_frame,
+    minimum_coherence
+)
