@@ -35,5 +35,6 @@ from cr.sparse._src.opt.smooth.huber import smooth_huber
 from cr.sparse._src.opt.smooth.linear import smooth_linear
 from cr.sparse._src.opt.smooth.logdet import smooth_logdet
 from cr.sparse._src.opt.smooth.quad import (
-    smooth_quad_matrix
+    smooth_quad_matrix,
+    smooth_quad_error
 )
